@@ -73,7 +73,7 @@ use namespace::autoclean 0.16;
 use version 0.77;
 
 # ABSTRACT: Frequently used operations on include files
-our $VERSION = 'v0.6.5'; # VERSION
+our $VERSION = 'v0.6.5_01'; # VERSION
 
 extends 'Dist::Zilla::File::InMemory';
 
@@ -227,10 +227,29 @@ sub munge {
 #pod
 #pod =cut
 
+{ package #
+    Dist::Zilla::Plugin::Templates::File::Encod;
+
+  # Pod::Text always encodes (as of 6.0.2 there's no way to turn that
+  # off), so provide a do-nothing decoder
+
+  use parent qw( Encode::Encoding );
+
+  sub encode ($$;$) {
+      my ( $obj, $str, $chk ) = @_;
+      $_[1] = '' if $chk;
+      return $str;
+
+  }
+
+  __PACKAGE__->Define( 'passthrough' );
+
+}
+
 sub pod2text {
     my ( $self, %opts ) = @_;
     my $name = $self->name;
-    my $parser = Pod::Text->new( %opts );
+    my $parser = Pod::Text->new( encoding => 'passthrough', %opts );
     my ( $text, $errata );
     $parser->output_string( \$text );
     if ( $parser->can( 'errata_seen' ) ) {
@@ -319,7 +338,7 @@ Dist::Zilla::Plugin::Templates::File - Frequently used operations on include fil
 
 =head1 VERSION
 
-Version v0.6.5, released on 2018-03-22 20:35 UTC.
+Version v0.6.5_01, released on 2018-03-22 20:35 UTC.
 
 =for test_synopsis BEGIN { die "SKIP: Not Perl code.\n" };
 
